@@ -187,9 +187,9 @@ C
       external kldist,lkern
       real*8 kldist,lkern
       integer n1,n2,n3,model,kern
-      logical aws,fix(1)
-      real*8 y(1),theta(1),bi(1),bi0(1),ai(1),lambda,wght(2),
-     1       bi2(1),hakt,lwght(1),spmin,spf,hhom(1)
+      logical aws,fix(*)
+      real*8 y(*),theta(*),bi(*),bi0(*),ai(*),lambda,wght(2),
+     1       bi2(*),hakt,lwght(*),spmin,spf,hhom(*)
       integer ih1,ih2,ih3,i1,i2,i3,j1,j2,j3,jw1,jw2,jw3,jwind3,jwind2,
      1        iind,jind,jind3,jind2,clw1,clw2,clw3,dlw1,dlw2,dlw3,
      2        dlw12,n12
@@ -197,16 +197,16 @@ C
      1       hmax2,hhomi,hhommax,w1,w2
       hakt2=hakt*hakt
       spf=1.d0/(1.d0-spmin)
-      ih1=hakt
+      ih1=FLOOR(hakt)
       aws=lambda.lt.1d35
 C
 C   first calculate location weights
 C
       w1=wght(1)
       w2=wght(2)
-      ih3=hakt/w2
-      ih2=hakt/w1
-      ih1=hakt
+      ih3=FLOOR(hakt/w2)
+      ih2=FLOOR(hakt/w1)
+      ih1=FLOOR(hakt)
       if(n3.eq.1) ih3=0
       if(n2.eq.1) ih2=0
       clw1=ih1
@@ -224,7 +224,7 @@ C
          if(n3.gt.1) THEN
             z3=j3*w2
             z3=z3*z3
-            ih2=sqrt(hakt2-z3)/w1
+            ih2=FLOOR(sqrt(hakt2-z3)/w1)
             jind3=(j3+clw3)*dlw12
          ELSE
             jind3=0
@@ -233,7 +233,7 @@ C
             if(n2.gt.1) THEN
                z2=j2*w1
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                jind2=jind3+(j2+clw2)*dlw1
             ELSE
                jind2=0
@@ -282,7 +282,7 @@ C   scaling of sij outside the loop
             jind3=(j3-1)*n12
             z3=jw3*w2
             z3=z3*z3
-            if(n2.gt.1) ih2=sqrt(hakt2-z3)/w1
+            if(n2.gt.1) ih2=FLOOR(sqrt(hakt2-z3)/w1)
             DO jw2=-ih2,ih2
                j2=jw2+i2
                if(j2.lt.1.or.j2.gt.n2) CYCLE
@@ -290,7 +290,7 @@ C   scaling of sij outside the loop
                jind2=(j2-1)*n1+jind3
                z2=jw2*w1
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                DO jw1=-ih1,ih1
 C  first stochastic term
                   j1=jw1+i1
@@ -332,6 +332,173 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 C
 C   Perform one iteration in local constant three-variate aws (gridded)
 C
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+      subroutine caws6(y,fix,n1,n2,n3,hakt,hhom,lambda,theta,fnc,bi,
+     1                 bi2,bi0,ai,model,kern,spmin,lwght,wght)
+C
+C   y        observed values of regression function
+C   n1,n2,n3    design dimensions
+C   hakt     actual bandwidth
+C   lambda   lambda or lambda*sigma2 for Gaussian models
+C   theta    estimates from last step   (input)
+C   bi       \sum  Wi   (output)
+C   ai       \sum  Wi Y     (output)
+C   model    specifies the probablilistic model for the KL-Distance
+C   kern     specifies the location kernel
+C   wght     scaling factor for second and third dimension (larger values shrink)
+C
+      implicit logical (a-z)
+
+      external kldist,lkern
+      real*8 kldist,lkern
+      integer n1,n2,n3,model,kern
+      logical aws,fix(*)
+      real*8 y(*),theta(*),bi(*),bi0(*),ai(*),lambda,wght(2),
+     1       bi2(*),hakt,lwght(*),spmin,spf,hhom(*),fnc(*)
+      integer ih1,ih2,ih3,i1,i2,i3,j1,j2,j3,jw1,jw2,jw3,jwind3,jwind2,
+     1        iind,jind,jind3,jind2,clw1,clw2,clw3,dlw1,dlw2,dlw3,
+     2        dlw12,n12
+      real*8 thetai,bii,sij,swj,swj2,swj0,swjy,z,z1,z2,z3,wj,hakt2,
+     1       hmax2,hhomi,hhommax,w1,w2,fnci
+      hakt2=hakt*hakt
+      spf=1.d0/(1.d0-spmin)
+      ih1=FLOOR(hakt)
+      aws=lambda.lt.1d35
+C
+C   first calculate location weights
+C
+      w1=wght(1)
+      w2=wght(2)
+      ih3=FLOOR(hakt/w2)
+      ih2=FLOOR(hakt/w1)
+      ih1=FLOOR(hakt)
+      if(n3.eq.1) ih3=0
+      if(n2.eq.1) ih2=0
+      clw1=ih1
+      clw2=ih2
+      clw3=ih3
+      dlw1=ih1+clw1+1
+      dlw2=ih2+clw2+1
+      dlw3=ih3+clw3+1
+      dlw12=dlw1*dlw2
+      n12=n1*n2
+      z2=0.d0
+      z3=0.d0
+      hmax2=0.d0
+      DO j3=-clw3,clw3
+         if(n3.gt.1) THEN
+            z3=j3*w2
+            z3=z3*z3
+            ih2=FLOOR(sqrt(hakt2-z3)/w1)
+            jind3=(j3+clw3)*dlw12
+         ELSE
+            jind3=0
+         END IF
+         DO j2=-ih2,ih2
+            if(n2.gt.1) THEN
+               z2=j2*w1
+               z2=z3+z2*z2
+               ih1=FLOOR(sqrt(hakt2-z2))
+               jind2=jind3+(j2+clw2)*dlw1
+            ELSE
+               jind2=0
+            END IF
+            DO j1=-ih1,ih1
+C  first stochastic term
+               jind=j1+clw1+1+jind2
+               z1=j1
+               lwght(jind)=lkern(kern,(z1*z1+z2)/hakt2)
+               if(lwght(jind).gt.0.d0) hmax2=max(hmax2,z2+z1*z1)
+            END DO
+         END DO
+      END DO
+      call rchkusr()
+C$OMP PARALLEL DEFAULT(NONE)
+C$OMP& SHARED(ai,bi,bi0,bi2,hhom,n1,n2,n3,hakt2,hmax2,theta,fnc,
+C$OMP& ih3,lwght,wght,y,fix)
+C$OMP& FIRSTPRIVATE(ih1,ih2,lambda,aws,n12,
+C$OMP& model,spmin,spf,dlw1,clw1,dlw2,clw2,dlw3,clw3,dlw12,w1,w2)
+C$OMP& PRIVATE(i1,i2,i3,iind,hhomi,hhommax,thetai,bii,swj,swj2,
+C$OMP& swj0,swjy,sij,wj,j3,jw3,jind3,z3,jwind3,j2,jw2,jind2,z2,jwind2,
+C$OMP& j1,jw1,jind,z1,fnci,z)
+C$OMP DO SCHEDULE(GUIDED)
+      DO iind=1,n1*n2*n3
+         i1=mod(iind,n1)
+         if(i1.eq.0) i1=n1
+         i2=mod((iind-i1)/n1+1,n2)
+         if(i2.eq.0) i2=n2
+         i3=(iind-i1-(i2-1)*n1)/n12+1         
+         hhomi=hhom(iind)
+         hhomi=hhomi*hhomi
+         hhommax=hmax2
+         IF (fix(iind)) CYCLE
+C    nothing to do, final estimate is already fixed by control 
+         thetai=theta(iind)
+         bii=bi(iind)/lambda
+         fnci=fnc(iind)
+C   scaling of sij outside the loop
+         swj=0.d0
+         swj2=0.d0
+         swj0=0.d0
+         swjy=0.d0
+         DO jw3=-clw3,clw3
+            j3=jw3+i3
+            if(j3.lt.1.or.j3.gt.n3) CYCLE
+            jwind3=(jw3+clw3)*dlw12
+            jind3=(j3-1)*n12
+            z3=jw3*w2
+            z3=z3*z3
+            if(n2.gt.1) ih2=FLOOR(sqrt(hakt2-z3)/w1)
+            DO jw2=-ih2,ih2
+               j2=jw2+i2
+               if(j2.lt.1.or.j2.gt.n2) CYCLE
+               jwind2=jwind3+(jw2+clw2)*dlw1
+               jind2=(j2-1)*n1+jind3
+               z2=jw2*w1
+               z2=z3+z2*z2
+               ih1=FLOOR(sqrt(hakt2-z2))
+               DO jw1=-ih1,ih1
+C  first stochastic term
+                  j1=jw1+i1
+                  if(j1.lt.1.or.j1.gt.n1) CYCLE
+                  jind=j1+jind2
+                  wj=lwght(jw1+clw1+1+jwind2)
+                  swj0=swj0+wj
+                  z1=jw1
+                  z1=z2+z1*z1
+                  IF (aws.and.z1.ge.hhomi) THEN
+                     z=thetai-theta(jind)
+                     sij=bii*z*z/(fnci+fnc(jind))
+                     IF (sij.gt.1.d0) THEN
+                        hhommax=min(hhommax,z1)
+                        CYCLE
+                     END IF
+                     IF (sij.gt.spmin) THEN
+                        wj=wj*(1.d0-spf*(sij-spmin))
+                        hhommax=min(hhommax,z1)
+                     END IF
+                  END IF
+                  swj=swj+wj
+                  swj2=swj2+wj*wj
+                  swjy=swjy+wj*y(jind)
+               END DO
+            END DO
+         END DO
+         ai(iind)=swjy
+         bi(iind)=swj
+         bi2(iind)=swj2
+         bi0(iind)=swj0
+         hhom(iind)=sqrt(hhommax)
+      END DO 
+C$OMP END DO NOWAIT
+C$OMP END PARALLEL
+C$OMP FLUSH(ai,bi,bi0,bi2,hhom)
+      RETURN
+      END
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+C
+C   Perform one iteration in local constant three-variate aws (gridded)
+C
 CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       subroutine cawsw(n1,n2,n3,hakt,lambda,theta,bi,
      1                model,kern,spmin,lwght,wght)
@@ -352,21 +519,20 @@ C
       external kldist,lkern
       real*8 kldist,lkern
       integer n1,n2,n3,model,kern
-      real*8 theta(1),bi(1),lambda,
-     1       wght(n1,n2,n3,n1,n2,n3),hakt,lwght(1),spmin,spf
+      real*8 theta(*),bi(*),lambda,
+     1       wght(n1,n2,n3,n1,n2,n3),hakt,lwght(*),spmin,spf
       integer ih1,ih2,ih3,i1,i2,i3,j1,j2,j3,jw1,jw2,jw3,jwind3,jwind2,
      1        iind,jind,jind3,jind2,clw1,clw2,clw3,dlw1,dlw2,dlw3,
      2        dlw12,n12
       real*8 thetai,bii,sij,z1,z2,z3,wj,hakt2,hmax2
       hakt2=hakt*hakt
       spf=1.d0/(1.d0-spmin)
-      ih1=hakt
 C
 C   first calculate location weights
 C
-      ih3=hakt
-      ih2=hakt
-      ih1=hakt
+      ih3=FLOOR(hakt)
+      ih2=ih3
+      ih1=ih3
       if(n3.eq.1) ih3=0
       if(n2.eq.1) ih2=0
       clw1=ih1
@@ -384,7 +550,7 @@ C
          if(n3.gt.1) THEN
             z3=j3
             z3=z3*z3
-            ih2=sqrt(hakt2-z3)
+            ih2=FLOOR(sqrt(hakt2-z3))
             jind3=(j3+clw3)*dlw12
          ELSE
             jind3=0
@@ -393,7 +559,7 @@ C
             if(n2.gt.1) THEN
                z2=j2
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                jind2=jind3+(j2+clw2)*dlw1
             ELSE
                jind2=0
@@ -433,7 +599,7 @@ C   scaling of sij outside the loop
             jind3=(j3-1)*n12
             z3=jw3
             z3=z3*z3
-            if(n2.gt.1) ih2=sqrt(hakt2-z3)
+            if(n2.gt.1) ih2=FLOOR(sqrt(hakt2-z3))
             DO jw2=-ih2,ih2
                j2=jw2+i2
                if(j2.lt.1.or.j2.gt.n2) CYCLE
@@ -441,7 +607,7 @@ C   scaling of sij outside the loop
                jind2=(j2-1)*n1+jind3
                z2=jw2
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                DO jw1=-ih1,ih1
 C  first stochastic term
                   j1=jw1+i1
@@ -488,8 +654,8 @@ C
       external kldist,lkern
       real*8 kldist,lkern
       integer n1,n2,n3,model,kern
-      real*8 y(1),bi(1),bi0(1),ai(1),wght(2),
-     1       bi2(1),hakt,lwght(1)
+      real*8 y(*),bi(*),bi0(*),ai(*),wght(2),
+     1       bi2(*),hakt,lwght(*)
       integer ih1,ih2,ih3,i1,i2,i3,j1,j2,j3,jw1,jw2,jw3,jwind3,jwind2,
      1        iind,jind,jind3,jind2,clw1,clw2,clw3,dlw1,dlw2,dlw3,
      2        dlw12,n12
@@ -497,13 +663,12 @@ C
       hakt2=hakt*hakt
       w1=wght(1)
       w2=wght(2)
-      ih1=hakt
 C
 C   first calculate location weights
 C
-      ih3=hakt/w2
-      ih2=hakt/w1
-      ih1=hakt
+      ih3=FLOOR(hakt/w2)
+      ih2=FLOOR(hakt/w1)
+      ih1=FLOOR(hakt)
       if(n3.eq.1) ih3=0
       if(n2.eq.1) ih2=0
       clw1=ih1
@@ -521,7 +686,7 @@ C
          if(n3.gt.1) THEN
             z3=j3*w2
             z3=z3*z3
-            ih2=sqrt(hakt2-z3)/w1
+            ih2=FLOOR(sqrt(hakt2-z3)/w1)
             jind3=(j3+clw3)*dlw12
          ELSE
             jind3=0
@@ -530,7 +695,7 @@ C
             if(n2.gt.1) THEN
                z2=j2*w1
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                jind2=jind3+(j2+clw2)*dlw1
             ELSE
                jind2=0
@@ -571,7 +736,7 @@ C    nothing to do, final estimate is already fixed by control
             jind3=(j3-1)*n12
             z3=jw3*w2
             z3=z3*z3
-            if(n2.gt.1) ih2=sqrt(hakt2-z3)/w1
+            if(n2.gt.1) ih2=FLOOR(sqrt(hakt2-z3)/w1)
             DO jw2=-ih2,ih2
                j2=jw2+i2
                if(j2.lt.1.or.j2.gt.n2) CYCLE
@@ -579,7 +744,7 @@ C    nothing to do, final estimate is already fixed by control
                jind2=(j2-1)*n1+jind3
                z2=jw2*w1
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                DO jw1=-ih1,ih1
 C  first stochastic term
                   j1=jw1+i1
@@ -628,9 +793,9 @@ C
       external kldist,lkern
       real*8 kldist,lkern
       integer n1,n2,n3,model,kern
-      logical aws,fix(1)
-      real*8 y(1),theta(1),bi(1),bi0(1),ai(1),lambda,wght(2),
-     1       bi2(1),hakt,lwght(1),si2(1),vred(1),spmin
+      logical aws,fix(*)
+      real*8 y(*),theta(*),bi(*),bi0(*),ai(*),lambda,wght(2),
+     1       bi2(*),hakt,lwght(*),si2(*),vred(*),spmin
       integer ih1,ih2,ih3,i1,i2,i3,j1,j2,j3,jw1,jw2,jw3,jwind3,jwind2,
      1        iind,jind,jind3,jind2,clw1,clw2,clw3,dlw1,dlw2,dlw3,
      2        dlw12,n12
@@ -640,14 +805,13 @@ C
       w2=wght(2)
       hakt2=hakt*hakt
       spf=1.d0/(1.d0-spmin)
-      ih1=hakt
       aws=lambda.lt.1d40
 C
 C   first calculate location weights
 C
-      ih3=hakt/w2
-      ih2=hakt/w1
-      ih1=hakt
+      ih3=FLOOR(hakt/w2)
+      ih2=FLOOR(hakt/w1)
+      ih1=FLOOR(hakt)
       if(n3.eq.1) ih3=0
       if(n2.eq.1) ih2=0
       clw1=ih1
@@ -664,7 +828,7 @@ C
          if(n3.gt.1) THEN
             z3=j3*w2
             z3=z3*z3
-            ih2=sqrt(hakt2-z3)/w1
+            ih2=FLOOR(sqrt(hakt2-z3)/w1)
             jind3=(j3+clw3)*dlw12
          ELSE
             jind3=0
@@ -673,7 +837,7 @@ C
             if(n2.gt.1) THEN
                z2=j2*w1
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                jind2=jind3+(j2+clw2)*dlw1
             ELSE
                jind2=0
@@ -721,7 +885,7 @@ C   scaling of sij outside the loop
             jind3=(j3-1)*n12
             z3=jw3*w2
             z3=z3*z3
-            if(n2.gt.1) ih2=sqrt(hakt2-z3)/w1
+            if(n2.gt.1) ih2=FLOOR(sqrt(hakt2-z3)/w1)
             jwind3=(jw3+clw3)*dlw12
             DO jw2=-ih2,ih2
                j2=jw2+i2
@@ -729,7 +893,7 @@ C   scaling of sij outside the loop
                jind2=(j2-1)*n1+jind3
                z2=jw2*w1
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                jwind2=jwind3+(jw2+clw2)*dlw1
                DO jw1=-ih1,ih1
 C  first stochastic term
@@ -787,8 +951,8 @@ C
       external lkern
       real*8 lkern
       integer n1,n2,n3,model,kern
-      real*8 y(1),bi(1),bi0(1),ai(1),wght(2),
-     1       bi2(1),hakt,lwght(1),si2(1),vred(1)
+      real*8 y(*),bi(*),bi0(*),ai(*),wght(2),
+     1       bi2(*),hakt,lwght(*),si2(*),vred(*)
       integer ih1,ih2,ih3,i1,i2,i3,j1,j2,j3,jw1,jw2,jw3,jwind3,jwind2,
      1        iind,jind,jind3,jind2,clw1,clw2,clw3,dlw1,dlw2,dlw3,
      2        dlw12,n12
@@ -796,13 +960,12 @@ C
       hakt2=hakt*hakt
       w1=wght(1)
       w2=wght(2)
-      ih1=hakt
 C
 C   first calculate location weights
 C
-      ih3=hakt/w2
-      ih2=hakt/w1
-      ih1=hakt
+      ih3=FLOOR(hakt/w2)
+      ih2=FLOOR(hakt/w1)
+      ih1=FLOOR(hakt)
       if(n3.eq.1) ih3=0
       if(n2.eq.1) ih2=0
       clw1=ih1
@@ -819,7 +982,7 @@ C
          if(n3.gt.1) THEN
             z3=j3*w2
             z3=z3*z3
-            ih2=sqrt(hakt2-z3)/w1
+            ih2=FLOOR(sqrt(hakt2-z3)/w1)
             jind3=(j3+clw3)*dlw12
          ELSE
             jind3=0
@@ -828,7 +991,7 @@ C
             if(n2.gt.1) THEN
                z2=j2*w1
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                jind2=jind3+(j2+clw2)*dlw1
             ELSE
                jind2=0
@@ -868,7 +1031,7 @@ C$OMP DO SCHEDULE(GUIDED)
             jind3=(j3-1)*n12
             z3=jw3*w2
             z3=z3*z3
-            if(n2.gt.1) ih2=sqrt(hakt2-z3)/w1
+            if(n2.gt.1) ih2=FLOOR(sqrt(hakt2-z3)/w1)
             jwind3=(jw3+clw3)*dlw12
             DO jw2=-ih2,ih2
                j2=jw2+i2
@@ -876,7 +1039,7 @@ C$OMP DO SCHEDULE(GUIDED)
                jind2=(j2-1)*n1+jind3
                z2=jw2*w1
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                jwind2=jwind3+(jw2+clw2)*dlw1
                DO jw1=-ih1,ih1
 C  first stochastic term
@@ -926,9 +1089,9 @@ C
       external lkern
       real*8 lkern
       integer n1,n2,n3,kern
-      logical aws,fix(1),mask(1)
-      real*8 y(1),theta(1),bi(1),bi0(1),ai(1),lambda,wght(2),
-     1       bi2(1),hakt,lwght(1),si2(1),vred(1),spmin,hhom(1),gi(1)
+      logical aws,fix(*),mask(*)
+      real*8 y(*),theta(*),bi(*),bi0(*),ai(*),lambda,wght(2),
+     1       bi2(*),hakt,lwght(*),si2(*),vred(*),spmin,hhom(*),gi(*)
       integer ih1,ih2,ih3,i1,i2,i3,j1,j2,j3,jw1,jw2,jw3,jwind3,jwind2,
      1        iind,jind,jind3,jind2,clw1,clw2,clw3,dlw1,dlw2,dlw3,
      2        dlw12,n12
@@ -938,14 +1101,13 @@ C
       spf=1.d0/(1.d0-spmin)
       w1=wght(1)
       w2=wght(2)
-      ih1=hakt
       aws=lambda.lt.1d40
 C
 C   first calculate location weights
 C
-      ih3=hakt/w2
-      ih2=hakt/w1
-      ih1=hakt
+      ih3=FLOOR(hakt/w2)
+      ih2=FLOOR(hakt/w1)
+      ih1=FLOOR(hakt)
       if(n3.eq.1) ih3=0
       if(n2.eq.1) ih2=0
       clw1=ih1
@@ -963,7 +1125,7 @@ C
          if(n3.gt.1) THEN
             z3=j3*w2
             z3=z3*z3
-            ih2=sqrt(hakt2-z3)/w1
+            ih2=FLOOR(sqrt(hakt2-z3)/w1)
             jind3=(j3+clw3)*dlw12
          ELSE
             jind3=0
@@ -972,7 +1134,7 @@ C
             if(n2.gt.1) THEN
                z2=j2*w1
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                jind2=jind3+(j2+clw2)*dlw1
             ELSE
                jind2=0
@@ -1024,7 +1186,7 @@ C   scaling of sij outside the loop
             jind3=(j3-1)*n12
             z3=jw3*w2
             z3=z3*z3
-            if(n2.gt.1) ih2=sqrt(hakt2-z3)/w1
+            if(n2.gt.1) ih2=FLOOR(sqrt(hakt2-z3)/w1)
             jwind3=(jw3+clw3)*dlw12
             DO jw2=-ih2,ih2
                j2=jw2+i2
@@ -1032,7 +1194,7 @@ C   scaling of sij outside the loop
                jind2=(j2-1)*n1+jind3
                z2=jw2*w1
                z2=z3+z2*z2
-               ih1=sqrt(hakt2-z2)
+               ih1=FLOOR(sqrt(hakt2-z2))
                jwind2=jwind3+(jw2+clw2)*dlw1
                DO jw1=-ih1,ih1
 C  first stochastic term
